aboutsummaryrefslogtreecommitdiffstats
path: root/examples/widgets/animation/easing/easing.py
diff options
context:
space:
mode:
Diffstat (limited to 'examples/widgets/animation/easing/easing.py')
-rw-r--r--examples/widgets/animation/easing/easing.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/examples/widgets/animation/easing/easing.py b/examples/widgets/animation/easing/easing.py
index d5c733863..647fbeb34 100644
--- a/examples/widgets/animation/easing/easing.py
+++ b/examples/widgets/animation/easing/easing.py
@@ -40,7 +40,7 @@
##
#############################################################################
-from PySide2 import QtCore, QtGui, QtWidgets
+from PySide6 import QtCore, QtGui, QtWidgets
import easing_rc
from ui_form import Ui_Form
@@ -83,7 +83,7 @@ class Animation(QtCore.QPropertyAnimation):
else:
super(Animation, self).updateCurrentTime(currentTime)
# PySide2 doesn't support deriving from more than one wrapped class so we use
# composition and delegate the property.
class Pixmap(QtCore.QObject):
def __init__(self, pix):
@@ -83,7 +83,7 @@ class Animation(QtCore.QPropertyAnimation):
else:
super(Animation, self).updateCurrentTime(currentTime)
-# PySide2 doesn't support deriving from more than one wrapped class so we use
+# PySide6 doesn't support deriving from more than one wrapped class so we use
# composition and delegate the property.
class Pixmap(QtCore.QObject):